@@ -16,7 +16,11 @@ from dictalchemy.tests import (
     WithHybrid,
     WithDefaultInclude,
     WithAttributeMappedCollection,
-    WithAttributeMappedCollectionChild
+    WithAttributeMappedCollectionChild,
+    DynamicRelationChild,
+    DynamicRelationParent,
+    ParentWithOptionalChild,
+    OptionalChild,
 )
 
 
@@ -215,3 +219,30 @@ class TestAsdict(TestCase):
         assert 'id' in dict(named)
         assert 'name' not in named.asdict(only=['id'], exclude=['id'])
         assert 'id' not in named.asdict(only=['name'], exclude=['name'])
+
+    def test_dynamic_relation(self):
+
+        child = DynamicRelationChild()
+        parent = DynamicRelationParent()
+        parent.childs.append(child)
+        self.session.add(parent)
+        self.session.add(child)
+        self.session.commit()
+        child_id = child.id
+        parent_id = parent.id
+        self.session.expire_all()
+        parent = self.session.query(DynamicRelationParent
+                                    ).filter_by(id=parent_id).first()
+        assert parent.asdict(follow={'childs':{}}
+                             )['childs'][0]['id'] == child_id
+
+    def test_nullable_fk_returns_none_relation(self):
+        parent = ParentWithOptionalChild()
+        self.session.add(parent)
+        self.session.commit()
+        assert parent.asdict(follow={'child':{}})['child'] == None
+        child = OptionalChild()
+        parent.child = child
+        self.session.add(child)
+        self.session.commit()
+        assert parent.asdict(follow={'child':{}})['child']['id'] == child.id
\ No newline at end of file
